"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var chalk = require("chalk");
var existsSync = fs.existsSync, lstatSync = fs.lstatSync, readFileSync = fs.readFileSync;
var LOG_LEVELS = {
    debug: {
        color: "white"
    },
    error: {
        color: "red"
    },
    info: {
        color: "cyan"
    },
    warn: {
        color: "yellow"
    }
};
function splitPath(partsPath) {
    var parts = partsPath.split(/(\/|\\)/);
    if (!parts.length) {
        return parts;
    }
    return !parts[0].length ? parts.slice(1) : parts;
}
function log(message, severity) {
    if (severity === void 0) { severity = "info"; }
    var color = LOG_LEVELS[severity].color || "cyan";
    if (process.env.SILENT !== "true") {
        console.log(chalk[color](message));
    }
}
exports.log = log;
function findParentDir(currentFullPath, clue) {
    function testDir(parts) {
        if (parts.length === 0) {
            return null;
        }
        var p = parts.join("");
        var itdoes = existsSync(path.join(p, clue));
        return itdoes ? p : testDir(parts.slice(0, -1));
    }
    return testDir(splitPath(currentFullPath));
}
exports.findParentDir = findParentDir;
function getGitFolder() {
    var dir = findParentDir(process.cwd(), ".git");
    if (!dir) {
        throw new Error("Cannot find .git folder");
    }
    var gitDir = path.join(dir, ".git");
    var stats = lstatSync(gitDir);
    if (!stats.isDirectory()) {
        var pathToGit = readFileSync(gitDir, "utf-8").split(":")[1].trim();
        gitDir = path.join(dir, pathToGit);
        if (!existsSync(gitDir)) {
            throw new Error("Cannot find file " + pathToGit);
        }
    }
    return gitDir;
}
exports.getGitFolder = getGitFolder;
