"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var helpers_1 = require("../helpers");
exports.semver = {
    validate: function (message) {
        var MAX_LENGTH = 100;
        var PATTERN = /^(?:fixup!\s*)?(\w*)(\(([\w\$\.\*/-]*)\))?\: (.*)$/;
        var TYPES = {
            build: true,
            chore: true,
            ci: true,
            docs: true,
            feat: true,
            fix: true,
            perf: true,
            refactor: true,
            revert: true,
            style: true,
            test: true
        };
        message = message.split("\n").shift();
        if (message.length >= MAX_LENGTH) {
            helpers_1.log("Message is longer than " + MAX_LENGTH + " characters!", "error");
            return false;
        }
        var match = PATTERN.exec(message);
        if (!match) {
            helpers_1.log("Message does not match these rules:\n        ======================================================\n        template  =>    \"<type>(jiraticket): commit message\"\n        example   =>    \"feat(kc-101): commit message\"\n        was       =>    \"" + message + "\"\n        ======================================================", "error");
            helpers_1.log("\n        ######################################################\n        ##### In your commit message, you should answer  #####\n        #####  1. Which Story is this commit belong to?  #####\n        #####  2. Who do this commit? (or pair)          #####\n        #####  3. Why do this commit?                    #####\n        ######################################################\n\n        ******************************************************\n        **************  Notes for your commit  ***************\n        ***   1. Make your commit Single Responsibility.   ***\n        ***   2. Make sure one sentence can describe all   ***\n        ***   things you have done in this commit clearly. ***\n        ******************************************************", "info");
            return false;
        }
        var type = match[1];
        if (!TYPES.hasOwnProperty(type)) {
            helpers_1.log("'" + type + "' is not an allowed type!", "error");
            helpers_1.log("Valid types are: " + Object.keys(TYPES).join(", "), "info");
            return false;
        }
        return true;
    },
    ignorePattern: /^WIP\:/
};
